clear all
close all
clc

global qH qL cH cL A B C D E F lambda lambdahat Delta  

% Parameters
qH = 1;
qL = 0.4;

cH = .09;
cL = .15;

lambda = 0.6;
lambdahat = lambda;
Delta = 1;

% Parameters of F



A = .5;
B = 13.3;
C = .4;
D = 2.8;
E = 2.2;
F = 0;

% For stability graph, use:
% A = .45;
% B = 13;
% C = .6;
% D = 2.6;
% E = 1.8;
% F = 0.1;

estar = (qH - qL)/cL
wstar = qH - cH*estar


N = 100;
pis = linspace(0.00001,.99999,N);

N2 = 1000
% Plot density
figure
thetas = linspace(0,lambda,N2);
figure(1)
plot(thetas,f(thetas))
xlabel('\theta')
ylabel('f(\theta)')


%% Plot equilibrium conditions

guesstheta = lambda-0.03;

for j = 1:N
    inds(j) = indif(pis(j));
    mcs(j) = mktclear2(pis(j),guesstheta);
    if j>1
        guesstheta = mcs(j-1);
    end
end

fighandle = figure(2)
plot(pis,inds,'b',pis,mcs,'r','LineWidth',1.2)
% [hx,hy] = format_ticks(gca,...
%                 {'$0$','$1$'},{'$0$','$\lambda$'},...
%                 [0,1],[0,lambda],[],[],[],'FontSize',20,'FontWeight','normal');
leg = legend('Indifference','Market Clearing');
set(leg,'Interpreter','Latex','Fontsize',15,'Location','NorthEast')
xlabel('$\pi$', 'Interpreter', 'Latex','FontSize', 20);
ylabel('$\theta$', 'Interpreter', 'Latex','FontSize', 20);




%% Find two equilibria

% Find equilibria near hand-picked points
pistar(1) = fzero(@(pi) equil(pi),0.1);
pistar(2) = fzero(@(pi) equil(pi),0.9);

for j = 1:2
    thetastar(j) = mktclear2(pistar(j),guesstheta);
    guesstheta = thetastar(j);
end

%% Compute profits in equilibrium and deviation

thetasdev(1,:)=linspace(thetastar(1),lambda,N)
thetasdev(2,:)=linspace(thetastar(2),lambda,N)

profits(1,:) = ((lambda - thetasdev(1,:))*qL + pistar(1)*(1-lambda)*qH)./...
    (lambda - thetasdev(1,:) + pistar(1)*(1-lambda))-wstar;

profits(2,:) = ((lambda - thetasdev(2,:))*qL + pistar(2)*(1-lambda)*qH)./...
    (lambda - thetasdev(2,:) + pistar(2)*(1-lambda))-wstar;

for j = 1:N
    wD(1,j) = qL + (qH - qL) * (1-cH/cL * integral(@(t) 1./(pistar(1)*(1-lambda)+lambda-t).*f(t),thetastar(1),thetasdev(1,j)));
    devprofits(1,j) = qH -wD(1,j);
    wD(2,j) = qL + (qH - qL) * (1-cH/cL * integral(@(t) 1./(pistar(2)*(1-lambda)+lambda-t).*f(t),thetastar(2),thetasdev(2,j)));
    devprofits(2,j) = qH -wD(2,j);
end

figure(3)
subplot(2,1,1);
plot(thetasdev(1,:),profits(1,:),thetasdev(1,:),devprofits(1,:))
legend('eq','dev')
subplot(2,1,2);
plot(thetasdev(2,:),profits(2,:),thetasdev(2,:),devprofits(2,:))
legend('eq','dev')


%% Plot for paper

fighandle = figure(4)

subplot(2,2,1)
plot(thetas,f(thetas),'b','LineWidth',1.2)
xlabel('$\theta$', 'Interpreter', 'Latex','FontSize', 8);
ylabel('$f(\theta)$', 'Interpreter', 'Latex','FontSize', 8);
[hx,hy] = format_ticks(gca,...
                {'$0$','$\lambda$'},{'$0$','$1$','$2$','$3$'},...
                [0,lambda],[0,1,2,3],[],[],[],'FontSize',6,'FontWeight','normal');
title('Distribution of Firms', 'Interpreter', 'Latex','FontSize', 8);
            
subplot(2,2,2)
plot(pis,inds,'b',pis,mcs,'r','LineWidth',1.2)
[hx,hy] = format_ticks(gca,...
                {'$0$','$\pi^*_1$','$\pi^*_2$','$1$'},{'$0$','$\theta^*_2$','$\theta^*_1$', '$\lambda$'},...
                [0,pistar(1),pistar(2),1],[0,thetastar(2),thetastar(1), lambda],[],[],[],'FontSize',6,'FontWeight','normal');
leg = legend('Indifference','Market Clearing');
set(leg,'Interpreter','Latex','Fontsize',6,'Location','North')
legend boxoff 
xlabel('$\pi$', 'Interpreter', 'Latex','FontSize', 8);
ylabel('$\theta$', 'Interpreter', 'Latex','FontSize', 8);   
hold on
plot(pistar,thetastar,'.k','markersize', 15)
plot([pistar(1),pistar(1)],[0,thetastar(1)],'--k',[0,pistar(1)],[thetastar(1),thetastar(1)],'--k',...  
    [pistar(2),pistar(2)],[0,thetastar(2)],'--k',[0,pistar(2)],[thetastar(2),thetastar(2)],'--k','LineWidth',0.5)
title('Equilibrium Conditions', 'Interpreter', 'Latex','FontSize', 8);

            
            
subplot(2,2,3)
plot(thetasdev(1,:),profits(1,:),'b',thetasdev(1,:),devprofits(1,:),'r','LineWidth',1.2)
[hx,hy] = format_ticks(gca,...
                {'$\theta^*_1$','$\lambda$'},{'$0$','$q_H - w^*$'},...
                [thetastar(1),lambda],[0,qH-wstar],[],[],[],'FontSize',6,'FontWeight','normal');
leg = legend('Equilibrium','Deviation');
set(leg,'Interpreter','Latex','Fontsize',6,'Location','NorthWest')
legend boxoff 
xlabel('$\theta$', 'Interpreter', 'Latex','FontSize', 8);
ylabel('Profit', 'Interpreter', 'Latex','FontSize', 8);   
title('Profits in Eq. 1', 'Interpreter', 'Latex','FontSize', 8);

         
         
subplot(2,2,4)
plot(thetasdev(2,:),profits(2,:),'b',thetasdev(2,:),devprofits(2,:),'r','LineWidth',1.2)
[hx,hy] = format_ticks(gca,...
                {'$\theta^*_2$','$\lambda$'},{'$0$','$q_H - w^*$'},...
                [thetastar(2),lambda],[0,qH-wstar],[],[],[],'FontSize',6,'FontWeight','normal');
leg = legend('Equilibrium','Deviation');
set(leg,'Interpreter','Latex','Fontsize',6,'Location','NorthWest')
legend boxoff 
xlabel('$\theta$', 'Interpreter', 'Latex','FontSize', 8);
ylabel('Profit', 'Interpreter', 'Latex','FontSize', 8);   
title('Profits in Eq. 2', 'Interpreter', 'Latex','FontSize', 8);

set(fighandle,'Position',[0 0 1000 700]);



