clear all
close all
clc

% This computes the regions of the parameter space where we have different types of equilibria

global qH qL cL lambda A e e2

% Parameters
qH = 1;
qL = 0.4;

lambda=.55;

cL = .27;


e = 1e-10;
e2 = 1e-3;

% Parameters of F
A = 1.2;  

%% Basics






%% Grid
NC = 55;
cH = linspace(0.07,0.095,NC);

NB = 280;
Bs = linspace(.1,7,NB);


%% Plot equilibrium conditions

M = 9;
pis = linspace(0.00001,.99999,M);
guesstheta = 0.5;


for k=1:NB
    k
    for j=1:NC
        
        estar = (qH - qL)./cL;
        wstar(j) = qH - cH(j)*estar;
        
        
        % Compute actual equilibrium
        t_ind_L = indif_regions_1(e2,cH(j));
        check_L = errmktclear_regions(e2,t_ind_L,lambda,Bs(k));
        t_ind_H = indif_regions_1(1-e2,cH(j));
        check_H = errmktclear_regions(1-e2,t_ind_H,lambda,Bs(k));
        
        if check_L<0
            pistar(j,k) = 0;
%             disp('Corner - separating')
        elseif check_H>0
%             disp('Corner - no signaling')
            pistar(j,k) = 1;
            if integral(@(t) 1./(1-t).*f_regions(t,lambda,Bs(k)),e,lambda)-1<0
                thetastar(j,k) = 0;
            else
                thetastar(j,k) = fzero(@(tt) integral(@(t) 1./(1-t).*f_regions(t,lambda,Bs(k)),tt,lambda)-1,[e;lambda-e]);
            end
        else
%             disp('Interior')
            pistar(j,k) = fzero(@(pi) equil_regions_1(pi,lambda,Bs(k),cH(j)),[e;1-e]);
            thetastar(j,k) = indif_regions_1(pistar(j,k),cH(j));
        end
        
        % Check deviations
        if pistar>0
            thetasdev = linspace(thetastar(j,k)+e,lambda-e,M);        
            profit =  ((lambda - thetasdev)*qL + pistar(j,k)*(1-lambda)*qH)./...
                (lambda - thetasdev + pistar(j,k)*(1-lambda))-wstar(j);
            for l = 1:M
                wD(l,j,k) = qL + (qH - qL) * (1-cH(j)./cL * integral(@(t) 1./(pistar(j,k)*(1-lambda)+lambda-t).*f_regions(t,lambda,Bs(k)),thetastar(j,k),thetasdev(l)));
                devprofit(l,j,k) = qH -wD(l,j,k);            
            end
            trueeq(j,k) = max(devprofit(:,j,k) -profit')<=0;
        else
            trueeq(j,k) = 1;
        end
        
        
    end
end

%% Color plot
close all


for j = 1:NC
     edge1(j) =Bs(find(pistar(j,:)>0,1));
     edge2(j) =Bs(find(pistar(j,:)==1,1));
    
end

    

figure(1)
h = area(cH,[edge1;edge2-edge1]','LineStyle','none');
h(1).FaceColor = [0.2 0.2 0.2];
h(2).FaceColor = [0.5 0.5 0.5];
xt = get(gca, 'XTick');
set(gca, 'FontSize', 14);
set(gca, 'YLim', [.5 5.5]);
plotTickLatex2D

xlabel('$c_H/c_L$', 'Interpreter', 'Latex','FontSize', 18);
ylabel('$A$', 'Interpreter', 'Latex','FontSize', 18);
text(0.075,1.5,'Pure Signaling','Interpreter', 'Latex','FontSize', 25,'Color',[1,1,1]);
text(0.071,4,'Partial Signaling','Interpreter', 'Latex','FontSize', 25,'Color',[1,1,1]);
text(0.081,4.1,'No Signaling','Interpreter', 'Latex','FontSize', 25,'Color',[0,0,0]);


return





