clear all
close all
clc

% This computes the regions of the parameter space where we have different types of equilibria

global qH qL cH cL A e e2 lambda

% Parameters
qH = 1;
qL = 0.4;

cH = .08;
cL = .27;

e = 1e-10;
e2 = 1e-3;

% Parameters of F
A = 1.2;  

%% Basics

estar = (qH - qL)/cL
wstar = qH - cH*estar

lambda=.55;


%% Grid
NL = 55;
lambda_hats = linspace(0.5,0.7,NL);

NB = 280;
Bs = linspace(.1,7,NB);


%% Plot equilibrium conditions

M = 9;
pis = linspace(0.00001,.99999,M);
guesstheta = 0.5;


for k=1:NB
    k
    for j=1:NL
        
        % Compute actual equilibrium
        t_ind_L = indif_regions(e2,lambda_hats(j));
        check_L = errmktclear_regions(e2,t_ind_L,lambda_hats(j),Bs(k));
        t_ind_H = indif_regions(1-e2,lambda_hats(j));
        check_H = errmktclear_regions(1-e2,t_ind_H,lambda_hats(j),Bs(k));
        
        if check_L<0
            pistar(j,k) = 0;
%             disp('Corner - separating')
        elseif check_H>0
%             disp('Corner - no signaling')
            pistar(j,k) = 1;
            if integral(@(t) 1./((lambda-t).*lambda_hats(j)./lambda+1-lambda_hats(j)).*f_regions(t,lambda,Bs(k)),e,lambda)-1<0
                thetastar(j,k) = 0;
            else
                thetastar(j,k) = fzero(@(tt) integral(@(t) 1./((lambda-t).*lambda_hats(j)./lambda+1-lambda_hats(j)).*f_regions(t,lambda,Bs(k)),tt,lambda)-1,[e;lambda-e]);
            end
        else
%             disp('Interior')
            pistar(j,k) = fzero(@(pi) equil_regions(pi,lambda_hats(j),Bs(k)),[e;1-e]);
            thetastar(j,k) = indif_regions(pistar(j,k),lambda_hats(j));
        end
        
        % Check deviations
        if pistar>0
            thetasdev = linspace(thetastar(j,k)+e,lambda-e,M);        
            profit =  ((lambda - thetasdev)*lambda_hats(j)./lambda*qL + pistar(j,k)*(1-lambda_hats(j))*qH)./...
                ((lambda - thetasdev).*lambda_hats(j)/lambda + pistar(j,k)*(1-lambda_hats(j)))-wstar;
            for l = 1:M
                wD(l,j,k) = qL + (qH - qL) * (1-cH/cL * integral(@(t) 1./(pistar(j,k)*(1-lambda_hats(j))+(lambda-t).*lambda_hats(j)./lambda).*f_regions(t,lambda,Bs(k)),thetastar(j,k),thetasdev(l)));
                devprofit(l,j,k) = qH -wD(l,j,k);            
            end
            trueeq(j,k) = max(devprofit(:,j,k) -profit')<=0;
        else
            trueeq(j,k) = 1;
        end
        
        
    end
end

%% Color plot
close all


for j = 1:NL
     edge1(j) =Bs(find(pistar(j,:)>0,1));
     edge2(j) =Bs(find(pistar(j,:)==1,1));
    
end

    

figure(1)
h = area(lambda_hats,[edge1;edge2-edge1]','LineStyle','none');
h(1).FaceColor = [0.2 0.2 0.2];
h(2).FaceColor = [0.5 0.5 0.5];
xt = get(gca, 'XTick');
set(gca, 'FontSize', 14);
set(gca, 'YLim', [1.5 6]);
plotTickLatex2D

xlabel('$\hat{\lambda}$', 'Interpreter', 'Latex','FontSize', 18);
ylabel('$A$', 'Interpreter', 'Latex','FontSize', 18);
text(0.6,2,'Pure Signaling','Interpreter', 'Latex','FontSize', 25,'Color',[1,1,1]);
text(0.56,3.5,'Partial Signaling','Interpreter', 'Latex','FontSize', 25,'Color',[1,1,1]);
text(0.52,4.5,'No Signaling','Interpreter', 'Latex','FontSize', 25,'Color',[0,0,0]);


return





